@@ -1,10 +1,15 @@
-from pathlib import Path
+#  Copyright (c) 2022, Manfred Moitzi
+#  License: MIT License
+import pathlib
 import ezdxf
 from ezdxf.entities import Hatch
 
 from ezdxf.tools.analyze import HatchAnalyzer
 
-DIR = Path("~/Desktop/Outbox").expanduser()
+CWD = pathlib.Path("~/Desktop/Outbox").expanduser()
+if not CWD.exists():
+    CWD = pathlib.Path(".")
+
 FILE = r"C:\Users\manfred\Desktop\Now\ezdxf\573\hatch_text_box_in_hole.dxf"
 
 doc = ezdxf.readfile(FILE)
@@ -16,4 +21,4 @@ hatch_analyzer = HatchAnalyzer(marker_size=10)
 hatch_analyzer.print_report(hatch)
 hatch_analyzer.add_hatch(hatch)
 hatch_analyzer.add_boundary_markers(hatch)
-hatch_analyzer.export(str(DIR / f"hatch_{handle}.dxf"))
+hatch_analyzer.export(str(CWD / f"hatch_{handle}.dxf"))
