@@ -54,8 +54,8 @@ class TestProE:
         doc, auditor = recover.readfile(filename)
         assert doc.filename == filename
         assert doc.dxfversion is not None
-        assert len(auditor.errors) == 2
-        assert len(auditor.fixes) == 9
+        assert len(auditor.errors) >= 2
+        assert len(auditor.fixes) >= 9
 
 
 FILE_CIVIL_3D = os.path.join(
