@@ -1,6 +1,7 @@
 #  Copyright (c) 2021, Manfred Moitzi
 #  License: MIT License
-from typing import Dict, NamedTuple, Optional, List
+from __future__ import annotations
+from typing import NamedTuple, Optional
 
 
 class Bookmark(NamedTuple):
@@ -10,8 +11,8 @@ class Bookmark(NamedTuple):
 
 
 class Bookmarks:
-    def __init__(self):
-        self.bookmarks: Dict[str, Bookmark] = dict()
+    def __init__(self) -> None:
+        self.bookmarks: dict[str, Bookmark] = dict()
 
     def add(self, name: str, handle: str, offset: int):
         self.bookmarks[name] = Bookmark(name, handle, offset)
@@ -19,7 +20,7 @@ class Bookmarks:
     def get(self, name: str) -> Optional[Bookmark]:
         return self.bookmarks.get(name)
 
-    def names(self) -> List[str]:
+    def names(self) -> list[str]:
         return list(self.bookmarks.keys())
 
     def discard(self, name: str):
