@@ -766,6 +766,8 @@ class UniversalFrontend:
             elif show_filename_if_missing:
                 default_cap_height = 20
                 text = image_def.dxf.filename
+                if not text.strip():
+                    text = "<no filename>"
                 font = self.pipeline.text_engine.get_font(
                     self.get_font_face(properties)
                 )
@@ -870,8 +872,6 @@ class UniversalFrontend:
 
     def draw_composite_entity(self, entity: DXFGraphic, properties: Properties) -> None:
         def draw_insert(insert: Insert):
-            # Block reference attributes are located __outside__ the block reference!
-            self.draw_entities(insert.attribs)
             clip = xclip.XClip(insert)
             is_clipping_active = clip.has_clipping_path and clip.is_clipping_enabled
 
@@ -903,6 +903,10 @@ class UniversalFrontend:
                 )
                 self.pipeline.pop_clipping_shape()
 
+            # Draw ATTRIB entities at last, see #1321
+            # Block reference attributes are located __outside__ the block reference!
+            self.draw_entities(insert.attribs)
+
         if isinstance(entity, Insert):
             self.ctx.push_state(properties)
             if entity.mcount > 1:
