@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2022, Manfred Moitzi
+# Copyright (c) 2019-2024, Manfred Moitzi
 # License: MIT License
 from __future__ import annotations
 from typing import TYPE_CHECKING, Iterable, Mapping, Optional
@@ -7,6 +7,7 @@ import json
 from ezdxf.sections.tables import TABLENAMES
 from ezdxf.lldxf.tags import Tags
 from ezdxf.entities import BoundaryPathType, EdgeType
+import numpy as np
 
 if TYPE_CHECKING:
     from ezdxf.lldxf.types import DXFTag
@@ -208,7 +209,7 @@ class Code:
         self.blocks.update(code.blocks)
 
         # append source code lines
-        self.add_lines(self.code, indent=indent)
+        self.add_lines(code.code, indent=indent)
 
 
 _PURGE_DXF_ATTRIBUTES = {
@@ -246,8 +247,17 @@ def _fmt_mapping(mapping: Mapping, indent: int = 0) -> Iterable[str]:
 
 
 def _fmt_list(l: Iterable, indent: int = 0) -> Iterable[str]:
+    def cleanup(values: Iterable) -> Iterable:
+        for value in values:
+            if isinstance(value, np.float64):
+                yield float(value)
+            else:
+                yield value
+
     fmt = " " * indent + "{},"
     for v in l:
+        if not isinstance(v, (float, int, str)):
+            v = tuple(cleanup(v))
         yield fmt.format(str(v))
 
 
@@ -760,7 +770,7 @@ class _SourceCodeGenerator:
             add_line(f"e.set_seed_points({entity.seeds})")
         if entity.pattern:
             self.add_list_source_code(
-                entity.pattern.lines,
+                map(str, entity.pattern.lines),
                 prolog="e.set_pattern_definition([",
                 epilog="])",
             )
