@@ -1,15 +1,7 @@
-#  Copyright (c) 2021-2022, Manfred Moitzi
+#  Copyright (c) 2021-2024, Manfred Moitzi
 #  License: MIT License
 from __future__ import annotations
-from typing import (
-    Union,
-    List,
-    Iterable,
-    Sequence,
-    Tuple,
-    Optional,
-    TYPE_CHECKING,
-)
+from typing import Union, Iterable, Sequence, Optional, TYPE_CHECKING
 import abc
 import enum
 import math
@@ -35,7 +27,7 @@ from ezdxf.math import (
 from ezdxf.math.transformtools import OCSTransform
 
 if TYPE_CHECKING:
-    from ezdxf.eztypes import TagWriter
+    from ezdxf.lldxf.tagwriter import AbstractTagWriter
 
 __all__ = [
     "BoundaryPaths",
@@ -69,23 +61,23 @@ class EdgeType(enum.IntEnum):
 class AbstractBoundaryPath(abc.ABC):
     type: BoundaryPathType
     path_type_flags: int
-    source_boundary_objects: List[str]
+    source_boundary_objects: list[str]
 
     @abc.abstractmethod
-    def clear(self) -> None:
-        ...
+    def clear(self) -> None: ...
 
     @classmethod
-    def load_tags(cls, tags: Tags) -> AbstractBoundaryPath:
-        ...
+    @abc.abstractmethod
+    def load_tags(cls, tags: Tags) -> AbstractBoundaryPath: ...
 
     @abc.abstractmethod
-    def export_dxf(self, tagwriter: TagWriter, dxftype: str) -> None:
-        ...
+    def export_dxf(self, tagwriter: AbstractTagWriter, dxftype: str) -> None: ...
 
     @abc.abstractmethod
-    def transform(self, ocs: OCSTransform, elevation: float) -> None:
-        ...
+    def transform(self, ocs: OCSTransform, elevation: float) -> None: ...
+
+    @abc.abstractmethod
+    def is_valid(self) -> bool: ...
 
 
 class AbstractEdge(abc.ABC):
@@ -93,26 +85,33 @@ class AbstractEdge(abc.ABC):
 
     @property
     @abc.abstractmethod
-    def start_point(self) -> Vec2:
-        ...
+    def start_point(self) -> Vec2: ...
 
     @property
     @abc.abstractmethod
-    def end_point(self) -> Vec2:
-        ...
+    def end_point(self) -> Vec2: ...
 
     @abc.abstractmethod
-    def export_dxf(self, tagwriter: TagWriter) -> None:
-        ...
+    def export_dxf(self, tagwriter: AbstractTagWriter) -> None: ...
 
     @abc.abstractmethod
-    def transform(self, ocs: OCSTransform, elevation: float) -> None:
-        ...
+    def transform(self, ocs: OCSTransform, elevation: float) -> None: ...
+
+    @abc.abstractmethod
+    def is_valid(self) -> bool: ...
+
+    @property
+    def real_start_point(self) -> Vec2:
+        return self.start_point
+
+    @property
+    def real_end_point(self) -> Vec2:
+        return self.end_point
 
 
 class BoundaryPaths:
-    def __init__(self, paths: List[AbstractBoundaryPath] = None):
-        self.paths: List[AbstractBoundaryPath] = paths or []
+    def __init__(self, paths: Optional[list[AbstractBoundaryPath]] = None):
+        self.paths: list[AbstractBoundaryPath] = paths or []
 
     def __len__(self):
         return len(self.paths)
@@ -120,6 +119,12 @@ class BoundaryPaths:
     def __getitem__(self, item):
         return self.paths[item]
 
+    def __iter__(self):
+        return iter(self.paths)
+
+    def is_valid(self) -> bool:
+        return all(p.is_valid() for p in self.paths)
+
     @classmethod
     def load_tags(cls, tags: Tags) -> BoundaryPaths:
         paths = []
@@ -159,9 +164,7 @@ class BoundaryPaths:
 
     def default_paths(self) -> Iterable[AbstractBoundaryPath]:
         """Iterable of default paths, could be empty."""
-        not_default = (
-            const.BOUNDARY_PATH_OUTERMOST + const.BOUNDARY_PATH_EXTERNAL
-        )
+        not_default = const.BOUNDARY_PATH_OUTERMOST + const.BOUNDARY_PATH_EXTERNAL
         for b in self.paths:
             if bool(b.path_type_flags & not_default) is False:
                 yield b
@@ -188,8 +191,7 @@ class BoundaryPaths:
             return 2
 
         paths = sorted(
-            (path_type_enum(p.path_type_flags), i, p)
-            for i, p in enumerate(self.paths)
+            (path_type_enum(p.path_type_flags), i, p) for i, p in enumerate(self.paths)
         )
         ignore = 1  # EXTERNAL only
         if hatch_style == const.HATCH_STYLE_NESTED:
@@ -198,9 +200,18 @@ class BoundaryPaths:
             ignore = 2
         return (p for path_type, _, p in paths if path_type < ignore)
 
+    def append(self, path: AbstractBoundaryPath) -> None:
+        """Append a new boundary path.
+
+        .. versionadded:: 1.4
+        """
+        if not isinstance(path, AbstractBoundaryPath):
+            raise TypeError(f"invalid path type: {type(path)}")
+        self.paths.append(path)
+
     def add_polyline_path(
         self,
-        path_vertices: Iterable[Tuple[float, ...]],
+        path_vertices: Iterable[tuple[float, ...]],
         is_closed: bool = True,
         flags: int = 1,
     ) -> PolylinePath:
@@ -210,26 +221,26 @@ class BoundaryPaths:
             path_vertices: iterable of polyline vertices as (x, y) or
                 (x, y, bulge)-tuples.
             is_closed: 1 for a closed polyline else 0
-            flags: external(1) or outermost(16) or default (0)
+            flags: default(0), external(1), derived(4), textbox(8) or outermost(16)
 
         """
         new_path = PolylinePath.from_vertices(path_vertices, is_closed, flags)
-        self.paths.append(new_path)
+        self.append(new_path)
         return new_path
 
     def add_edge_path(self, flags: int = 1) -> EdgePath:
         """Create and add a new :class:`EdgePath` object.
 
         Args:
-            flags: external(1) or outermost(16) or default (0)
+            flags: default(0), external(1), derived(4), textbox(8) or outermost(16)
 
         """
         new_path = EdgePath()
         new_path.path_type_flags = flags
-        self.paths.append(new_path)
+        self.append(new_path)
         return new_path
 
-    def export_dxf(self, tagwriter: TagWriter, dxftype: str) -> None:
+    def export_dxf(self, tagwriter: AbstractTagWriter, dxftype: str) -> None:
         tagwriter.write_tag2(91, len(self.paths))
         for path in self.paths:
             path.export_dxf(tagwriter, dxftype)
@@ -257,8 +268,8 @@ class BoundaryPaths:
         """
 
         def _edges(points) -> Iterable[Union[LineEdge, ArcEdge]]:
-            prev_point = None
-            prev_bulge = None
+            prev_point: Vec3 | None = None
+            prev_bulge: float = 0.0
             for x, y, bulge in points:
                 point = Vec3(x, y)
                 if prev_point is None:
@@ -266,7 +277,7 @@ class BoundaryPaths:
                     prev_bulge = bulge
                     continue
 
-                if prev_bulge != 0:
+                if prev_bulge != 0.0:
                     arc = ArcEdge()
                     # bulge_to_arc returns always counter-clockwise oriented
                     # start- and end angles:
@@ -276,15 +287,13 @@ class BoundaryPaths:
                         end_angle,
                         arc.radius,
                     ) = bulge_to_arc(prev_point, point, prev_bulge)
-                    chk_point = arc.center + Vec2.from_angle(
-                        start_angle, arc.radius
-                    )
+                    chk_point = arc.center + Vec2.from_angle(start_angle, arc.radius)
                     arc.ccw = chk_point.isclose(prev_point, abs_tol=1e-9)
                     arc.start_angle = math.degrees(start_angle) % 360.0
                     arc.end_angle = math.degrees(end_angle) % 360.0
-                    if math.isclose(
-                        arc.start_angle, arc.end_angle
-                    ) and math.isclose(arc.start_angle, 0):
+                    if math.isclose(arc.start_angle, arc.end_angle) and math.isclose(
+                        arc.start_angle, 0
+                    ):
                         arc.end_angle = 360.0
                     yield arc
                 else:
@@ -298,7 +307,7 @@ class BoundaryPaths:
 
         def to_edge_path(polyline_path) -> EdgePath:
             edge_path = EdgePath()
-            vertices: List = list(polyline_path.vertices)
+            vertices: list = list(polyline_path.vertices)
             if polyline_path.is_closed:
                 vertices.append(vertices[0])
             edge_path.edges = list(_edges(vertices))
@@ -448,9 +457,7 @@ class BoundaryPaths:
                 start_param=edge.start_param,
                 end_param=edge.end_param,
             )
-            segment_count = max(
-                int(float(num) * ellipse.param_span / math.tau), 3
-            )
+            segment_count = max(int(float(num) * ellipse.param_span / math.tau), 3)
             params = ellipse.params(segment_count + 1)
 
             # Reverse path if necessary!
@@ -523,7 +530,7 @@ class BoundaryPaths:
 
 def flatten_to_polyline_path(
     path: AbstractBoundaryPath, distance: float, segments: int = 16
-) -> "PolylinePath":
+) -> PolylinePath:
     import ezdxf.path  # avoid cyclic imports
 
     # keep path in original OCS!
@@ -535,7 +542,7 @@ def flatten_to_polyline_path(
     )
 
 
-def pop_source_boundary_objects_tags(path_tags: Tags) -> List[str]:
+def pop_source_boundary_objects_tags(path_tags: Tags) -> list[str]:
     source_boundary_object_tags = []
     while len(path_tags):
         if path_tags[-1].code in (97, 330):
@@ -553,7 +560,7 @@ def pop_source_boundary_objects_tags(path_tags: Tags) -> List[str]:
 
 
 def export_source_boundary_objects(
-    tagwriter: "TagWriter", handles: Sequence[str]
+    tagwriter: AbstractTagWriter, handles: Sequence[str]
 ):
     tagwriter.write_tag2(97, len(handles))
     for handle in handles:
@@ -563,40 +570,42 @@ def export_source_boundary_objects(
 class PolylinePath(AbstractBoundaryPath):
     type = BoundaryPathType.POLYLINE
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.path_type_flags: int = const.BOUNDARY_PATH_POLYLINE
         self.is_closed = False
-        # List of 2D coordinates with bulge values (x, y, bulge);
+        # list of 2D coordinates with bulge values (x, y, bulge);
         # bulge default = 0.0
-        self.vertices: List[Tuple[float, float, float]] = []
+        self.vertices: list[tuple[float, float, float]] = []
         # MPOLYGON does not support source boundary objects, the MPOLYGON is
         # the source object!
-        self.source_boundary_objects: List[str] = []  # (330, handle) tags
+        self.source_boundary_objects: list[str] = []  # (330, handle) tags
+
+    def is_valid(self) -> bool:
+        return True
 
     @classmethod
     def from_vertices(
         cls,
-        path_vertices: Iterable[Tuple[float, ...]],
+        path_vertices: Iterable[tuple[float, ...]],
         is_closed: bool = True,
         flags: int = 1,
-    ) -> "PolylinePath":
+    ) -> PolylinePath:
         """Create a new :class:`PolylinePath` object from vertices.
 
         Args:
             path_vertices: iterable of polyline vertices as (x, y) or
                 (x, y, bulge)-tuples.
             is_closed: 1 for a closed polyline else 0
-            flags: external(1) or outermost(16) or default (0)
+            flags: default(0), external(1), derived(4), textbox(8) or outermost(16)
 
         """
-
         new_path = PolylinePath()
         new_path.set_vertices(path_vertices, is_closed)
         new_path.path_type_flags = flags | const.BOUNDARY_PATH_POLYLINE
         return new_path
 
     @classmethod
-    def load_tags(cls, tags: Tags) -> "PolylinePath":
+    def load_tags(cls, tags: Tags) -> PolylinePath:
         path = PolylinePath()
         path.source_boundary_objects = pop_source_boundary_objects_tags(tags)
         for tag in tags:
@@ -651,7 +660,7 @@ class PolylinePath(AbstractBoundaryPath):
     def has_bulge(self) -> bool:
         return any(bulge for x, y, bulge in self.vertices)
 
-    def export_dxf(self, tagwriter: "TagWriter", dxftype: str) -> None:
+    def export_dxf(self, tagwriter: AbstractTagWriter, dxftype: str) -> None:
         has_bulge = self.has_bulge()
         write_tag = tagwriter.write_tag2
 
@@ -671,9 +680,7 @@ class PolylinePath(AbstractBoundaryPath):
                 write_tag(42, float(bulge))
 
         if dxftype == "HATCH":
-            export_source_boundary_objects(
-                tagwriter, self.source_boundary_objects
-            )
+            export_source_boundary_objects(tagwriter, self.source_boundary_objects)
 
     def transform(self, ocs: OCSTransform, elevation: float) -> None:
         """Transform polyline path."""
@@ -698,41 +705,35 @@ class PolylinePath(AbstractBoundaryPath):
 class EdgePath(AbstractBoundaryPath):
     type = BoundaryPathType.EDGE
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.path_type_flags = const.BOUNDARY_PATH_DEFAULT
-        self.edges: List[AbstractEdge] = []
+        self.edges: list[AbstractEdge] = []
         self.source_boundary_objects = []
 
     def __iter__(self):
         return iter(self.edges)
 
-    @classmethod
-    def load_tags(cls, tags: Tags) -> "EdgePath":
-        edge_path = cls()
-        edge_path.source_boundary_objects = pop_source_boundary_objects_tags(
-            tags
-        )
-        edge_groups = group_tags(tags, splitcode=72)
-        for edge_tags in edge_groups:
-            edge_path.edges.append(edge_path.load_edge(edge_tags))
-        return edge_path
+    def is_valid(self) -> bool:
+        return all(e.is_valid() for e in self.edges)
 
-    @staticmethod
-    def load_edge(tags: Tags) -> AbstractEdge:
-        edge_type = tags[0].value
-        if 0 < edge_type < 5:
-            return EDGE_CLASSES[edge_type].load_tags(tags[1:])
-        else:
-            raise const.DXFStructureError(
-                f"HATCH: unknown edge type: {edge_type}"
-            )
+    @classmethod
+    def load_tags(cls, tags: Tags) -> EdgePath:
+        edge_path = cls()
+        edge_path.source_boundary_objects = pop_source_boundary_objects_tags(tags)
+        for edge_tags in group_tags(tags, splitcode=72):
+            if len(edge_tags) == 0:
+                continue
+            edge_type = edge_tags[0].value
+            if 0 < edge_type < 5:
+                edge_path.edges.append(EDGE_CLASSES[edge_type].load_tags(edge_tags[1:]))
+        return edge_path
 
     def transform(self, ocs: OCSTransform, elevation: float) -> None:
         """Transform edge boundary paths."""
         for edge in self.edges:
             edge.transform(ocs, elevation=elevation)
 
-    def add_line(self, start: UVec, end: UVec) -> "LineEdge":
+    def add_line(self, start: UVec, end: UVec) -> LineEdge:
         """Add a :class:`LineEdge` from `start` to `end`.
 
         Args:
@@ -753,7 +754,7 @@ class EdgePath(AbstractBoundaryPath):
         start_angle: float = 0.0,
         end_angle: float = 360.0,
         ccw: bool = True,
-    ) -> "ArcEdge":
+    ) -> ArcEdge:
         """Add an :class:`ArcEdge`.
 
         **Adding Clockwise Oriented Arcs:**
@@ -776,7 +777,7 @@ class EdgePath(AbstractBoundaryPath):
                 clockwise oriented arc)
             end_angle: end angle of arc in degrees (`start_angle` for a
                 clockwise oriented arc)
-            ccw: ``True`` for counter clockwise ``False`` for
+            ccw: ``True`` for counter-clockwise ``False`` for
                 clockwise orientation
 
         """
@@ -824,7 +825,7 @@ class EdgePath(AbstractBoundaryPath):
                 clockwise oriented ellipse)
             end_angle: end angle of ellipse in degrees (`start_angle` for a
                 clockwise oriented ellipse)
-            ccw: ``True`` for counter clockwise ``False`` for
+            ccw: ``True`` for counter-clockwise ``False`` for
                 clockwise orientation
 
         """
@@ -847,14 +848,14 @@ class EdgePath(AbstractBoundaryPath):
 
     def add_spline(
         self,
-        fit_points: Iterable[UVec] = None,
-        control_points: Iterable[UVec] = None,
-        knot_values: Iterable[float] = None,
-        weights: Iterable[float] = None,
+        fit_points: Optional[Iterable[UVec]] = None,
+        control_points: Optional[Iterable[UVec]] = None,
+        knot_values: Optional[Iterable[float]] = None,
+        weights: Optional[Iterable[float]] = None,
         degree: int = 3,
         periodic: int = 0,
-        start_tangent: UVec = None,
-        end_tangent: UVec = None,
+        start_tangent: Optional[UVec] = None,
+        end_tangent: Optional[UVec] = None,
     ) -> SplineEdge:
         """Add a :class:`SplineEdge`.
 
@@ -906,7 +907,7 @@ class EdgePath(AbstractBoundaryPath):
 
     def add_spline_control_frame(
         self,
-        fit_points: Iterable[Tuple[float, float]],
+        fit_points: Iterable[tuple[float, float]],
         degree: int = 3,
         method: str = "distance",
     ) -> SplineEdge:
@@ -923,13 +924,40 @@ class EdgePath(AbstractBoundaryPath):
         """Delete all edges."""
         self.edges = []
 
-    def export_dxf(self, tagwriter: "TagWriter", dxftype: str) -> None:
+    def export_dxf(self, tagwriter: AbstractTagWriter, dxftype: str) -> None:
         tagwriter.write_tag2(92, int(self.path_type_flags))
         tagwriter.write_tag2(93, len(self.edges))
         for edge in self.edges:
             edge.export_dxf(tagwriter)
         export_source_boundary_objects(tagwriter, self.source_boundary_objects)
 
+    def close_gaps(self, len_tol: float) -> None:
+        """Insert line-edges between the existing edges if the gap between these edges
+        are bigger than `len_tol`.
+
+        .. versionadded:: 1.4
+
+        """
+        if len(self.edges) < 2:
+            return
+        current_edges = list(self.edges)
+        first_edge = current_edges.pop(0)
+        current_edges.append(first_edge)
+
+        new_edges: list[AbstractEdge] = [first_edge]
+        end_point = first_edge.real_end_point
+        for edge in current_edges:
+            start_point = edge.real_start_point
+            if end_point.distance(start_point) > len_tol:
+                line_edge = LineEdge()
+                line_edge.start = end_point
+                line_edge.end = start_point
+                new_edges.append(line_edge)
+            if edge is not first_edge:
+                new_edges.append(edge)
+            end_point = edge.real_end_point
+        self.edges = new_edges
+
 
 class LineEdge(AbstractEdge):
     EDGE_TYPE = "LineEdge"  # 2021-05-31: deprecated use type
@@ -939,6 +967,9 @@ class LineEdge(AbstractEdge):
         self.start = Vec2(0, 0)  # OCS!
         self.end = Vec2(0, 0)  # OCS!
 
+    def is_valid(self) -> bool:
+        return True
+
     @property
     def start_point(self) -> Vec2:
         return self.start
@@ -958,7 +989,7 @@ class LineEdge(AbstractEdge):
                 edge.end = Vec2(value)
         return edge
 
-    def export_dxf(self, tagwriter: TagWriter) -> None:
+    def export_dxf(self, tagwriter: AbstractTagWriter) -> None:
         tagwriter.write_tag2(72, 1)  # edge type
 
         x, y, *_ = self.start
@@ -978,7 +1009,7 @@ class ArcEdge(AbstractEdge):
     type = EdgeType.ARC  # 2021-05-31: deprecated use type
     EDGE_TYPE = "ArcEdge"
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.center = Vec2(0.0, 0.0)
         self.radius: float = 1.0
         # Start- and end angles are always stored in counter-clockwise order!
@@ -987,14 +1018,29 @@ class ArcEdge(AbstractEdge):
         # Flag to preserve the required orientation for DXF export:
         self.ccw: bool = True
 
+    def is_valid(self) -> bool:
+        return True
+
     @property
     def start_point(self) -> Vec2:
         return self.construction_tool().start_point
 
+    @property
+    def real_start_point(self) -> Vec2:
+        if self.ccw:
+            return self.start_point
+        return self.end_point
+
     @property
     def end_point(self) -> Vec2:
         return self.construction_tool().end_point
 
+    @property
+    def real_end_point(self) -> Vec2:
+        if self.ccw:
+            return self.end_point
+        return self.start_point
+
     @classmethod
     def load_tags(cls, tags: Tags) -> ArcEdge:
         edge = cls()
@@ -1028,7 +1074,7 @@ class ArcEdge(AbstractEdge):
             edge.end_angle = 360.0 - start
         return edge
 
-    def export_dxf(self, tagwriter: TagWriter) -> None:
+    def export_dxf(self, tagwriter: AbstractTagWriter) -> None:
         tagwriter.write_tag2(72, 2)  # edge type
         x, y, *_ = self.center
         if self.ccw:
@@ -1081,7 +1127,7 @@ class EllipseEdge(AbstractEdge):
     EDGE_TYPE = "EllipseEdge"  # 2021-05-31: deprecated use type
     type = EdgeType.ELLIPSE
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.center = Vec2((0.0, 0.0))
         # Endpoint of major axis relative to center point (in OCS)
         self.major_axis = Vec2((1.0, 0.0))
@@ -1092,6 +1138,9 @@ class EllipseEdge(AbstractEdge):
         # Flag to preserve the required orientation for DXF export:
         self.ccw: bool = True
 
+    def is_valid(self) -> bool:
+        return True
+
     @property
     def start_point(self) -> Vec2:
         return self.construction_tool().start_point.vec2
@@ -1100,6 +1149,18 @@ class EllipseEdge(AbstractEdge):
     def end_point(self) -> Vec2:
         return self.construction_tool().end_point.vec2
 
+    @property
+    def real_start_point(self) -> Vec2:
+        if self.ccw:
+            return self.start_point
+        return self.end_point
+
+    @property
+    def real_end_point(self) -> Vec2:
+        if self.ccw:
+            return self.end_point
+        return self.start_point
+
     @property
     def start_param(self) -> float:
         return angle_to_param(self.ratio, math.radians(self.start_angle))
@@ -1152,7 +1213,7 @@ class EllipseEdge(AbstractEdge):
 
         return edge
 
-    def export_dxf(self, tagwriter: TagWriter) -> None:
+    def export_dxf(self, tagwriter: AbstractTagWriter) -> None:
         tagwriter.write_tag2(72, 3)  # edge type
         x, y, *_ = self.center
         tagwriter.write_tag2(10, float(x))
@@ -1201,8 +1262,8 @@ class EllipseEdge(AbstractEdge):
 
         # Transform WCS representation to new OCS
         wcs_to_ocs = ocs.new_ocs.from_wcs
-        self.center = wcs_to_ocs(e.center).vec2  # type: ignore
-        self.major_axis = wcs_to_ocs(e.major_axis).vec2  # type: ignore
+        self.center = wcs_to_ocs(e.center).vec2
+        self.major_axis = wcs_to_ocs(e.major_axis).vec2
         self.ratio = e.ratio
 
         # ConstructionEllipse() is always in ccw orientation
@@ -1229,18 +1290,31 @@ class SplineEdge(AbstractEdge):
     EDGE_TYPE = "SplineEdge"  # 2021-05-31: deprecated use type
     type = EdgeType.SPLINE
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.degree: int = 3  # code = 94
         self.rational: int = 0  # code = 73
         self.periodic: int = 0  # code = 74
-        self.knot_values: List[float] = []
-        self.control_points: List[Vec2] = []
-        self.fit_points: List[Vec2] = []
-        self.weights: List[float] = []
+        self.knot_values: list[float] = []
+        self.control_points: list[Vec2] = []
+        self.fit_points: list[Vec2] = []
+        self.weights: list[float] = []
         # do not set tangents by default to (0, 0)
         self.start_tangent: Optional[Vec2] = None
         self.end_tangent: Optional[Vec2] = None
 
+    def is_valid(self) -> bool:
+        if len(self.control_points):
+            order = self.degree + 1
+            count = len(self.control_points)
+            if order > count:
+                return False
+            required_knot_count = count + order
+            if len(self.knot_values) != required_knot_count:
+                return False
+        elif len(self.fit_points) < 2:
+            return False
+        return True
+
     @property
     def start_point(self) -> Vec2:
         return self.control_points[0]
@@ -1274,8 +1348,8 @@ class SplineEdge(AbstractEdge):
                 edge.end_tangent = Vec2(value)
         return edge
 
-    def export_dxf(self, tagwriter: TagWriter) -> None:
-        def set_required_tangents(points: List[Vec2]):
+    def export_dxf(self, tagwriter: AbstractTagWriter) -> None:
+        def set_required_tangents(points: list[Vec2]):
             if len(points) > 1:
                 if self.start_tangent is None:
                     self.start_tangent = points[1] - points[0]
@@ -1306,9 +1380,7 @@ class SplineEdge(AbstractEdge):
             for value in self.knot_values:
                 write_tag(40, float(value))
         else:
-            raise const.DXFValueError(
-                "SplineEdge: missing required knot values"
-            )
+            raise const.DXFValueError("SplineEdge: missing required knot values")
 
         # build control points
         # control points have to be present and valid, otherwise AutoCAD crashes
