@@ -1,7 +1,9 @@
-# Copyright (c) 2019-2022 Manfred Moitzi
+# Copyright (c) 2019-2024 Manfred Moitzi
 # License: MIT License
 from __future__ import annotations
 from typing import TYPE_CHECKING, Optional, Union, Iterable, Iterator
+from typing_extensions import Self
+
 import math
 import logging
 from ezdxf.audit import AuditError
@@ -36,6 +38,7 @@ from .dxfentity import base_class, SubclassProcessor
 from .dxfgfx import DXFGraphic, acdb_entity
 from .factory import register_entity
 from .dimstyleoverride import DimStyleOverride
+from .copy import default_copy, CopyNotSupported
 
 if TYPE_CHECKING:
     from ezdxf.entities import DXFNamespace, DXFEntity, DimStyle
@@ -46,6 +49,7 @@ if TYPE_CHECKING:
     from ezdxf.math import OCS
     from ezdxf import xref
 
+
 logger = logging.getLogger("ezdxf")
 ADSK_CONSTRAINTS = "*ADSK_CONSTRAINTS"
 
@@ -337,7 +341,7 @@ class OverrideMixin:
             if dxf_attr and dxf_attr.code > 0:
                 if dxf_attr.dxfversion > actual_dxfversion:
                     logger.debug(
-                        f'Unsupported DIMSTYLE attribute "{key}" for '  # type: ignore
+                        f'Unsupported DIMSTYLE attribute "{key}" for '
                         f"DXF version {self.doc.acad_release}"  # type: ignore
                     )
                     continue
@@ -410,7 +414,7 @@ class OverrideMixin:
 
         # transform block record handles into block names
         for attrib_name in ("dimblk", "dimblk1", "dimblk2", "dimldrblk"):
-            blkrec_handle = data.pop(attrib_name + "_handle", None)
+            blkrec_handle = data.pop(attrib_name + "_handle", "")
             if blkrec_handle:
                 set_arrow_name(attrib_name, blkrec_handle)
 
@@ -429,7 +433,7 @@ class OverrideMixin:
 
         # transform linetype handles into LTYPE entry names
         for attrib_name in ("dimltype", "dimltex1", "dimltex2"):
-            handle = data.pop(attrib_name + "_handle", None)
+            handle = data.pop(attrib_name + "_handle", "")
             if handle:
                 set_ltype_name(attrib_name, handle)
         return data
@@ -482,18 +486,20 @@ class Dimension(DXFGraphic, OverrideMixin):
         # store the content of the geometry block for virtual entities
         self.virtual_block_content: Optional[EntitySpace] = None
 
-    def copy(self) -> Dimension:
-        virtual_copy = super().copy()
+    def copy(self, copy_strategy=default_copy) -> Dimension:
+        virtual_copy: Dimension = super().copy(copy_strategy=copy_strategy)  # type: ignore
         # The new virtual copy can not reference the same geometry block as the
         # original dimension entity:
         virtual_copy.dxf.discard("geometry")
-        return virtual_copy  # type: ignore
+        return virtual_copy
 
-    def copy_data(self, entity: DXFEntity) -> None:
+    def copy_data(self, entity: Self, copy_strategy=default_copy) -> None:
         assert isinstance(entity, Dimension)
         if self.virtual_block_content:
             # another copy of a virtual entity:
-            virtual_content = EntitySpace(e.copy() for e in self.virtual_block_content)
+            virtual_content = EntitySpace(
+                copy_strategy.copy(e) for e in self.virtual_block_content
+            )
         else:
             # entity is a new virtual copy of self and can not share the same
             # geometry block to be independently transformable:
@@ -503,10 +509,6 @@ class Dimension(DXFGraphic, OverrideMixin):
             entity.dxf.discard("insert")
         entity.virtual_block_content = virtual_content
 
-    def copy_external(self) -> Dimension:
-        # virtual content is not required
-        return self.raw_copy()  # type: ignore
-
     def post_bind_hook(self):
         """Called after binding a virtual dimension entity to a document.
 
@@ -517,7 +519,7 @@ class Dimension(DXFGraphic, OverrideMixin):
         doc = self.doc
         if self.virtual_block_content and doc is not None:
             # create a new geometry block:
-            block = self.doc.blocks.new_anonymous_block(type_char="D")
+            block = doc.blocks.new_anonymous_block(type_char="D")
             # move virtual block content to the new geometry block:
             for entity in self.virtual_block_content:
                 block.add_entity(entity)
@@ -647,7 +649,7 @@ class Dimension(DXFGraphic, OverrideMixin):
             # overridden resources are referenced by name
             self.override().register_resources_r12(registry)
 
-    def map_resources(self, clone: DXFEntity, mapping: xref.ResourceMapper) -> None:
+    def map_resources(self, clone: Self, mapping: xref.ResourceMapper) -> None:
         super().map_resources(clone, mapping)
         clone.dxf.dimstyle = mapping.get_dim_style(self.dxf.dimstyle)
         clone.dxf.geometry = mapping.get_block_name(self.dxf.geometry)
@@ -802,17 +804,16 @@ class Dimension(DXFGraphic, OverrideMixin):
 
         ocs = self.ocs()
         dim_elevation = self.dxf.text_midpoint.z
-        transform = False
+        m: Matrix44 | None = None
         insert = self.dxf.get("insert", None)
         if insert:
-            transform = True
-            insert = ocs.to_wcs(insert)
+            insert = Vec3(ocs.to_wcs(insert))
             m = Matrix44.translate(insert.x, insert.y, insert.z)
 
         for entity in self._block_content():
             try:
-                copy = entity.copy()
-            except DXFTypeError:
+                copy = entity.copy(copy_strategy=default_copy)
+            except CopyNotSupported:
                 continue
 
             if ocs.transform:
@@ -821,8 +822,7 @@ class Dimension(DXFGraphic, OverrideMixin):
                 # POINT:
                 ocs_to_wcs(copy, dim_elevation)
 
-            if transform:
-                # noinspection PyUnboundLocalVariable
+            if m is not None:
                 copy.transform(m)
             yield copy
 
@@ -976,7 +976,7 @@ class ArcDimension(Dimension):
         )
         self.dxf.dimtype = dimtype  # restore original dimtype
 
-    def transform(self, m: Matrix44) -> Dimension:
+    def transform(self, m: Matrix44) -> Self:
         """Transform the ARC_DIMENSION entity by transformation matrix `m` inplace.
 
         Raises ``NonUniformScalingError()`` for non uniform scaling.
@@ -1045,7 +1045,7 @@ class RadialDimensionLarge(Dimension):
             ["chord_point", "override_center", "jog_point", "unknown2"],
         )
 
-    def transform(self, m: Matrix44) -> Dimension:
+    def transform(self, m: Matrix44) -> Self:
         """Transform the LARGE_RADIAL_DIMENSION entity by transformation matrix
         `m` inplace.
 
@@ -1212,8 +1212,8 @@ def linear_measurement(
         # angle in WCS xy-plane
         measurement_direction = Vec3.from_angle(angle)
 
-    t1 = measurement_direction.project(p1)  # type: ignore
-    t2 = measurement_direction.project(p2)  # type: ignore
+    t1 = measurement_direction.project(p1)
+    t2 = measurement_direction.project(p2)
     return (t2 - t1).magnitude
 
 
