@@ -1,6 +1,7 @@
 # Copyright (c) 2019-2022, Manfred Moitzi
 # License: MIT License
-from typing import TYPE_CHECKING, Tuple
+from __future__ import annotations
+from typing import TYPE_CHECKING, Optional
 import logging
 from ezdxf.lldxf import validator, const
 from ezdxf.lldxf.attributes import (
@@ -15,13 +16,13 @@ from ezdxf.entities.dxfentity import base_class, SubclassProcessor, DXFEntity
 from ezdxf.entities.layer import acdb_symbol_table_record
 from .factory import register_entity
 
-logger = logging.getLogger("ezdxf")
-
 if TYPE_CHECKING:
-    from ezdxf.eztypes import TagWriter, DXFNamespace
-    from ezdxf.tools.fonts import AbstractFont
+    from ezdxf.entities import DXFNamespace
+    from ezdxf.lldxf.tagwriter import AbstractTagWriter
+    from ezdxf.fonts import fonts
 
 __all__ = ["Textstyle"]
+logger = logging.getLogger("ezdxf")
 
 acdb_style = DefSubclass(
     "AcDbTextStyleTableRecord",
@@ -34,7 +35,7 @@ acdb_style = DefSubclass(
         # Flags: Standard flag values (bit-coded values):
         # 1 = If set, this entry describes a shape
         # 4 = Vertical text
-        # 16 = If set, table entry is externally dependent on an xref
+        # 16 = If set, table entry is externally dependent on a xref
         # 32 = If both this bit and bit 16 are set, the externally dependent xref ...
         # 64 = If set, the table entry was referenced by at least one entity in ...
         # Vertical text works only for SHX fonts in AutoCAD and BricsCAD
@@ -64,7 +65,7 @@ acdb_style = DefSubclass(
         # Primary font file name:
         # ATTENTION: The font file name can be an empty string and the font family
         # may be stored in XDATA! See also posts at the (unrelated) issue #380.
-        "font": DXFAttr(3, default="txt"),
+        "font": DXFAttr(3, default=const.DEFAULT_TEXT_FONT),
         # Big font name, blank if none
         "bigfont": DXFAttr(4, default=""),
     },
@@ -89,18 +90,18 @@ class Textstyle(DXFEntity):
 
     DXFTYPE = "STYLE"
     DXFATTRIBS = DXFAttributes(base_class, acdb_symbol_table_record, acdb_style)
-    BOLD = 0b01000000000000000000000000
-    ITALIC = 0b10000000000000000000000000
+    ITALIC = 0b01000000000000000000000000
+    BOLD = 0b10000000000000000000000000
 
     def load_dxf_attribs(
-        self, processor: SubclassProcessor = None
-    ) -> "DXFNamespace":
+        self, processor: Optional[SubclassProcessor] = None
+    ) -> DXFNamespace:
         dxf = super().load_dxf_attribs(processor)
         if processor:
             processor.simple_dxfattribs_loader(dxf, acdb_style_group_codes)  # type: ignore
         return dxf
 
-    def export_entity(self, tagwriter: "TagWriter") -> None:
+    def export_entity(self, tagwriter: AbstractTagWriter) -> None:
         super().export_entity(tagwriter)
         if tagwriter.dxfversion > DXF12:
             tagwriter.write_tag2(SUBCLASS_MARKER, acdb_symbol_table_record.name)
@@ -126,7 +127,7 @@ class Textstyle(DXFEntity):
         """Returns ``True`` if extended font data is present."""
         return self.has_xdata("ACAD")
 
-    def get_extended_font_data(self) -> Tuple[str, bool, bool]:
+    def get_extended_font_data(self) -> tuple[str, bool, bool]:
         """Returns extended font data as tuple (font-family, italic-flag,
         bold-flag).
 
@@ -204,9 +205,16 @@ class Textstyle(DXFEntity):
     def is_vertical_stacked(self, state) -> None:
         self.set_flag_state(const.VERTICAL_STACKED, state, "flags")
 
+    @property
+    def is_shape_file(self) -> bool:
+        """``True`` if entry describes a shape."""
+        return self.dxf.name == "" and bool(self.dxf.flags & 1)
+
     def make_font(
-        self, cap_height: float = None, width_factor: float = None
-    ) -> "AbstractFont":
+        self,
+        cap_height: Optional[float] = None,
+        width_factor: Optional[float] = None,
+    ) -> fonts.AbstractFont:
         """Returns a font abstraction :class:`~ezdxf.tools.fonts.AbstractFont`
         for this text style. Returns a font for a cap height of 1, if the
         text style has auto height (:attr:`Textstyle.dxf.height` is 0) and
@@ -215,19 +223,18 @@ class Textstyle(DXFEntity):
         is ``None`` or 0, the default value is 1.
         The attribute :attr:`Textstyle.dxf.big_font` is ignored.
         """
-        from ezdxf import options
-        from ezdxf.tools import fonts
+        from ezdxf.fonts import fonts
 
         ttf = ""
-        if options.use_matplotlib and self.has_extended_font_data:
+        if self.has_extended_font_data:
             family, italic, bold = self.get_extended_font_data()
             if family:
-                text_style = "italic" if italic else "normal"
-                text_weight = "bold" if bold else "normal"
+                text_style = "Italic" if italic else "Regular"
+                text_weight = 700 if bold else 400
                 font_face = fonts.FontFace(
                     family=family, style=text_style, weight=text_weight
                 )
-                ttf = fonts.find_ttf_path(font_face)
+                ttf = fonts.find_font_file_name(font_face)
         else:
             ttf = self.dxf.get("font", const.DEFAULT_TTF)
         if ttf == "":
