@@ -1,6 +1,7 @@
-# Copyright (c) 2019-2021 Manfred Moitzi
+# Copyright (c) 2019-2022 Manfred Moitzi
 # License: MIT License
-from typing import TYPE_CHECKING
+from __future__ import annotations
+from typing import TYPE_CHECKING, Optional
 from ezdxf.lldxf import validator
 from ezdxf.lldxf.attributes import (
     DXFAttr,
@@ -17,7 +18,8 @@ from .dxfgfx import DXFGraphic, acdb_entity
 from .factory import register_entity
 
 if TYPE_CHECKING:
-    from ezdxf.eztypes import TagWriter, DXFNamespace
+    from ezdxf.entities import DXFNamespace
+    from ezdxf.lldxf.tagwriter import AbstractTagWriter
 
 __all__ = ["Ray", "XLine"]
 
@@ -47,8 +49,8 @@ class XLine(DXFGraphic):
     XLINE_SUBCLASS = "AcDbXline"
 
     def load_dxf_attribs(
-        self, processor: SubclassProcessor = None
-    ) -> "DXFNamespace":
+        self, processor: Optional[SubclassProcessor] = None
+    ) -> DXFNamespace:
         dxf = super().load_dxf_attribs(processor)
         if processor:
             processor.fast_load_dxfattribs(
@@ -56,13 +58,13 @@ class XLine(DXFGraphic):
             )
         return dxf
 
-    def export_entity(self, tagwriter: "TagWriter") -> None:
+    def export_entity(self, tagwriter: AbstractTagWriter) -> None:
         """Export entity specific data as DXF tags."""
         super().export_entity(tagwriter)
         tagwriter.write_tag2(SUBCLASS_MARKER, self.XLINE_SUBCLASS)
         self.dxf.export_dxf_attribs(tagwriter, ["start", "unit_vector"])
 
-    def transform(self, m: Matrix44) -> "XLine":
+    def transform(self, m: Matrix44) -> XLine:
         """Transform the XLINE/RAY entity by transformation matrix `m` inplace."""
         self.dxf.start = m.transform(self.dxf.start)
         self.dxf.unit_vector = m.transform_direction(
@@ -71,7 +73,7 @@ class XLine(DXFGraphic):
         self.post_transform(m)
         return self
 
-    def translate(self, dx: float, dy: float, dz: float) -> "XLine":
+    def translate(self, dx: float, dy: float, dz: float) -> XLine:
         """Optimized XLINE/RAY translation about `dx` in x-axis, `dy` in
         y-axis and `dz` in z-axis.
 
