@@ -1,7 +1,7 @@
 # Copyright (c) 2018-2022 Manfred Moitzi
 # License: MIT License
 from __future__ import annotations
-from typing import Iterable, List, Tuple, Sequence, Iterator, Callable
+from typing import Iterable, Sequence, Iterator, Callable, Optional
 import math
 from enum import IntEnum
 from ezdxf.math import (
@@ -14,6 +14,7 @@ from ezdxf.math import (
     arc_angle_span_rad,
     NULLVEC,
     Z_AXIS,
+    X_AXIS,
     UCS,
     intersection_ray_ray_3d,
 )
@@ -151,15 +152,10 @@ def euler_spiral(
         yield vertex.replace(z=elevation)
 
 
-def square(size: float = 1.0, center=False) -> Tuple[Vec3, Vec3, Vec3, Vec3]:
+def square(size: float = 1.0, center=False) -> tuple[Vec3, Vec3, Vec3, Vec3]:
     """Returns 4 vertices for a square with a side length of the given `size`.
     The center of the square in (0, 0) if `center` is ``True`` otherwise
     the lower left corner is (0, 0), upper right corner is (`size`, `size`).
-
-    .. versionchanged:: 0.18
-
-        added argument `center`
-
     """
     if center:
         a = size / 2.0
@@ -170,15 +166,10 @@ def square(size: float = 1.0, center=False) -> Tuple[Vec3, Vec3, Vec3, Vec3]:
 
 def box(
     sx: float = 1.0, sy: float = 1.0, center=False
-) -> Tuple[Vec3, Vec3, Vec3, Vec3]:
+) -> tuple[Vec3, Vec3, Vec3, Vec3]:
     """Returns 4 vertices for a box with a width of `sx` by and a height of
     `sy`. The center of the box in (0, 0) if `center` is ``True`` otherwise
     the lower left corner is (0, 0), upper right corner is (`sx`, `sy`).
-
-    .. versionchanged:: 0.18
-
-        added argument `center`
-
     """
     if center:
         a = sx / 2.0
@@ -188,9 +179,7 @@ def box(
         return Vec3(0, 0), Vec3(sx, 0), Vec3(sx, sy), Vec3(0, sy)
 
 
-def open_arrow(
-    size: float = 1.0, angle: float = 30.0
-) -> Tuple[Vec3, Vec3, Vec3]:
+def open_arrow(size: float = 1.0, angle: float = 30.0) -> tuple[Vec3, Vec3, Vec3]:
     """Returns 3 vertices for an open arrow `<` with a length of the given
     `size`, argument `angle` defines the enclosing angle in degrees.
     Vertex order: upward end vertex, tip (0, 0) , downward end vertex (counter-
@@ -207,7 +196,7 @@ def open_arrow(
 
 def arrow2(
     size: float = 1.0, angle: float = 30.0, beta: float = 45.0
-) -> Tuple[Vec3, Vec3, Vec3, Vec3]:
+) -> tuple[Vec3, Vec3, Vec3, Vec3]:
     """Returns 4 vertices for an arrow with a length of the given `size`, and
     an enclosing `angle` in degrees and a slanted back side defined by angle
     `beta`::
@@ -251,8 +240,8 @@ def arrow2(
 
 def ngon(
     count: int,
-    length: float = None,
-    radius: float = None,
+    length: Optional[float] = None,
+    radius: Optional[float] = None,
     rotation: float = 0.0,
     elevation: float = 0.0,
     close: bool = False,
@@ -406,12 +395,8 @@ def gear(
         raise ValueError("Argument `height` has to be smaller than `radius`")
 
     base_radius = outside_radius - height
-    alpha_top = math.asin(
-        top_width / 2.0 / outside_radius
-    )  # angle at tooth top
-    alpha_bottom = math.asin(
-        bottom_width / 2.0 / base_radius
-    )  # angle at tooth bottom
+    alpha_top = math.asin(top_width / 2.0 / outside_radius)  # angle at tooth top
+    alpha_bottom = math.asin(bottom_width / 2.0 / base_radius)  # angle at tooth bottom
     alpha_difference = (
         alpha_bottom - alpha_top
     ) / 2.0  # alpha difference at start and end of tooth
@@ -491,9 +476,7 @@ def turtle(commands: str, start=Vec2(0, 0), angle: float = 0) -> Iterator[Vec2]:
             yield cursor
 
 
-def translate(
-    vertices: Iterable[UVec], vec: UVec = (0, 0, 0)
-) -> Iterable[Vec3]:
+def translate(vertices: Iterable[UVec], vec: UVec = (0, 0, 0)) -> Iterable[Vec3]:
     """Translate `vertices` along `vec`, faster than a Matrix44 transformation.
 
     Args:
@@ -546,11 +529,11 @@ def scale(vertices: Iterable[UVec], scaling=(1.0, 1.0, 1.0)) -> Iterable[Vec3]:
 
 def close_polygon(
     vertices: Iterable[Vec3], rel_tol: float = 1e-9, abs_tol: float = 1e-12
-) -> List[Vec3]:
+) -> list[Vec3]:
     """Returns list of :class:`~ezdxf.math.Vec3`, where the first vertex is
     equal to the last vertex.
     """
-    polygon: List[Vec3] = list(vertices)
+    polygon: list[Vec3] = list(vertices)
     if not polygon[0].isclose(polygon[-1], rel_tol=rel_tol, abs_tol=abs_tol):
         polygon.append(polygon[0])
     return polygon
@@ -574,8 +557,6 @@ def helix(
         resolution: vertices per turn
         ccw: creates a counter-clockwise turning (right-handed) helix if ``True``
 
-    .. versionadded:: 0.18
-
     """
     step: float = 1.0 / max(resolution, 1)
     if not ccw:
@@ -657,10 +638,6 @@ def extrude(
 
     Returns: :class:`~ezdxf.render.MeshTransformer`
 
-    .. versionchanged:: 0.18
-
-        added parameter `caps` to close hull with top- and bottom faces
-
     """
     mesh = MeshVertexMerger()
     sweeping_profile = Vec3.list(profile)
@@ -683,7 +660,7 @@ def extrude(
     return MeshTransformer.from_builder(mesh)
 
 
-def _partial_path_factors(path: List[Vec3]) -> List[float]:
+def _partial_path_factors(path: list[Vec3]) -> list[float]:
     partial_lengths = [v1.distance(v2) for v1, v2 in zip(path, path[1:])]
     total_length = sum(partial_lengths)
     factors = [0.0]
@@ -694,10 +671,8 @@ def _partial_path_factors(path: List[Vec3]) -> List[float]:
     return factors
 
 
-def _divide_path_into_steps(
-    path: Sequence[Vec3], max_step_size: float
-) -> List[Vec3]:
-    new_path: List[Vec3] = [path[0]]
+def _divide_path_into_steps(path: Sequence[Vec3], max_step_size: float) -> list[Vec3]:
+    new_path: list[Vec3] = [path[0]]
     for v0, v1 in zip(path, path[1:]):
         segment_vec = v1 - v0
         length = segment_vec.magnitude
@@ -750,8 +725,6 @@ def extrude_twist_scale(
         quads: use quads for "sweeping" faces if ``True`` else triangles,
             the top and bottom faces are always ngons
 
-    .. versionadded:: 0.18
-
     Returns: :class:`~ezdxf.render.MeshTransformer`
 
     """
@@ -787,9 +760,7 @@ def extrude_twist_scale(
     prev_profile = sweeping_profile
     face_generator = _quad_connection_faces if quads else _tri_connection_faces
     for target_point, factor in zip(extrusion_path[1:], factors[1:]):
-        target_profile = list(
-            matrix(factor).transform_vertices(sweeping_profile)
-        )
+        target_profile = list(matrix(factor).transform_vertices(sweeping_profile))
         for face in face_generator(prev_profile, target_profile):
             mesh.add_face(face)
         prev_profile = target_profile
@@ -801,7 +772,7 @@ def extrude_twist_scale(
 def cylinder(
     count: int = 16,
     radius: float = 1.0,
-    top_radius: float = None,
+    top_radius: Optional[float] = None,
     top_center: UVec = (0, 0, 1),
     *,
     caps=True,
@@ -817,10 +788,6 @@ def cylinder(
         top_center: location vector for the center of the top profile
         caps: close hull with top- and  bottom faces (ngons)
 
-    .. versionchanged: 0.18
-
-        removed `ngons` argument
-
     """
     if top_radius is None:
         top_radius = radius
@@ -829,9 +796,7 @@ def cylinder(
         return cone(count=count, radius=radius, apex=top_center)
 
     base_profile = list(circle(count, radius, close=True))
-    top_profile = list(
-        translate(circle(count, top_radius, close=True), top_center)
-    )
+    top_profile = list(translate(circle(count, top_radius, close=True), top_center))
     return from_profiles_linear(
         [base_profile, top_profile],
         close=False,
@@ -843,36 +808,39 @@ def cylinder(
 def cylinder_2p(
     count: int = 16,
     radius: float = 1,
-    base_center=(0, 0, 0),
-    top_center=(0, 0, 1),
+    base_center: UVec = (0, 0, 0),
+    top_center: UVec = (0, 0, 1),
+    *,
     caps=True,
 ) -> MeshTransformer:
-    """Create a `cylinder <https://en.wikipedia.org/wiki/Cylinder>`_ as
+    """Creates a `cylinder <https://en.wikipedia.org/wiki/Cylinder>`_ as
     :class:`~ezdxf.render.MeshTransformer` object from two points,
     `base_center` is the center of the base circle and, `top_center` the center
     of the top circle.
 
     Args:
-        count: profiles edge count
+        count: cylinder profile edge count
         radius: radius for bottom profile
         base_center: center of base circle
         top_center: center of top circle
         caps: close hull with top- and  bottom faces (ngons)
 
-    Returns: :class:`~ezdxf.render.MeshTransformer`
-
-    .. versionchanged: 0.18
-
-        added `caps` argument
+    Raises:
+        ValueError: the cylinder orientation cannot be detected (base center == top center)
 
     """
-
     origin = Vec3(base_center)
     heading = Vec3(top_center) - origin
-    mesh = cylinder(
-        count, radius, top_center=(0, 0, heading.magnitude), caps=caps
-    )
-    ucs = reference_frame_z(heading, origin=origin)
+    if heading.is_null:
+        raise ValueError(
+            "cylinder orientation cannot be detected (base center == top center)"
+        )
+    mesh = cylinder(count, radius, top_center=(0, 0, heading.magnitude), caps=caps)
+    try:
+        ucs = UCS(origin=origin, uy=Z_AXIS.cross(heading), uz=heading)
+    except ZeroDivisionError:
+        # heading vector is parallel to the z-axis
+        ucs = UCS(origin=origin, ux=X_AXIS, uz=heading)
     mesh.transform(ucs.matrix)
     return mesh
 
@@ -893,18 +861,12 @@ def from_profiles_linear(
         quads: use quadrilaterals as connection faces if ``True`` else triangles
         caps: close hull with top- and bottom faces (ngons)
 
-    .. versionchanged: 0.18
-
-        restrict type of argument `profiles`, added argument `quads`
-
     """
     mesh = MeshVertexMerger()
     if close:
         profiles = [close_polygon(p) for p in profiles]
     if caps:
-        mesh.add_face(
-            reversed(profiles[0])
-        )  # for correct outside pointing normals
+        mesh.add_face(reversed(profiles[0]))  # for correct outside pointing normals
     face_generator = _quad_connection_faces if quads else _tri_connection_faces
     for p0, p1 in zip(profiles, profiles[1:]):
         for face in face_generator(p0, p1):
@@ -919,7 +881,7 @@ def spline_interpolation(
     degree: int = 3,
     method: str = "chord",
     subdivide: int = 4,
-) -> List[Vec3]:
+) -> list[Vec3]:
     """B-spline interpolation, vertices are fit points for the spline
     definition.
 
@@ -936,15 +898,13 @@ def spline_interpolation(
 
     """
     vertices = list(vertices)
-    spline = global_bspline_interpolation(
-        vertices, degree=degree, method=method
-    )
+    spline = global_bspline_interpolation(vertices, degree=degree, method=method)
     return list(spline.approximate(segments=(len(vertices) - 1) * subdivide))
 
 
 def spline_interpolated_profiles(
     profiles: Sequence[Sequence[Vec3]], subdivide: int = 4
-) -> Iterable[List[Vec3]]:
+) -> Iterable[list[Vec3]]:
     """Profile interpolation by cubic B-spline interpolation.
 
     Args:
@@ -954,19 +914,13 @@ def spline_interpolated_profiles(
 
     Returns: yields profiles as list of vertices
 
-    .. versionchanged: 0.18
-
-        restrict type of argument profiles
-
     """
 
     if len(set(len(p) for p in profiles)) != 1:
         raise ValueError("All profiles have to have the same vertex count")
 
     vertex_count = len(profiles[0])
-    edges = (
-        []
-    )  # interpolated spline vertices, where profile vertices are fit points
+    edges = []  # interpolated spline vertices, where profile vertices are fit points
     for index in range(vertex_count):
         edge_vertices = [p[index] for p in profiles]
         edges.append(spline_interpolation(edge_vertices, subdivide=subdivide))
@@ -997,10 +951,6 @@ def from_profiles_spline(
         quads: use quadrilaterals as connection faces if ``True`` else triangles
         caps: close hull with top- and bottom faces (ngons)
 
-    .. versionchanged: 0.18
-
-        restrict type of argument profiles, added argument `quads`
-
     """
     if len(profiles) > 3:
         profiles = list(spline_interpolated_profiles(profiles, subdivide))
@@ -1031,10 +981,6 @@ def cone(
         apex: tip of the cone
         caps: add a bottom face as ngon if ``True``
 
-    .. versionchanged: 0.18
-
-        removed `ngons` argument
-
     """
     mesh = MeshVertexMerger()
     base_circle = list(circle(count, radius, close=True))
@@ -1049,8 +995,8 @@ def cone(
 def cone_2p(
     count: int = 16,
     radius: float = 1.0,
-    base_center=(0, 0, 0),
-    apex=(0, 0, 1),
+    base_center: UVec = (0, 0, 0),
+    apex: UVec = (0, 0, 1),
     *,
     caps=True,
 ) -> MeshTransformer:
@@ -1065,15 +1011,23 @@ def cone_2p(
         apex: tip of the cone
         caps: add a bottom face as ngon if ``True``
 
-    .. versionchanged: 0.18
-
-        added `caps` argument
+    Raises:
+        ValueError: the cone orientation cannot be detected (base center == apex)
 
     """
     origin = Vec3(base_center)
     heading = Vec3(apex) - origin
+    if heading.is_null:
+        raise ValueError(
+            "the cone orientation cannot be detected (base center == apex)"
+        )
+
     mesh = cone(count, radius, apex=(0, 0, heading.magnitude), caps=caps)
-    ucs = reference_frame_z(heading, origin=origin)
+    try:
+        ucs = UCS(origin=origin, uy=Z_AXIS.cross(heading), uz=heading)
+    except ZeroDivisionError:
+        # heading vector is parallel to the z-axis
+        ucs = UCS(origin=origin, ux=X_AXIS, uz=heading)
     mesh.transform(ucs.matrix)
     return mesh
 
@@ -1096,10 +1050,6 @@ def rotation_form(
         axis: rotation axis
         caps: close hull with start- and end faces (ngons)
 
-    .. versionchanged:: 0.18
-
-        added arguments `caps` and `triangulation`
-
     """
     if count < 3:
         raise ValueError("count >= 2")
@@ -1217,8 +1167,6 @@ def torus(
         end_angle: end angle of torus in radians
         caps: close hull with start- and end faces (ngons) if the torus is open
 
-    .. versionadded:: 0.18
-
     """
     if major_count < 1:
         raise ValueError(f"major_count < 1")
@@ -1270,11 +1218,9 @@ def torus(
 
 
 def connection_faces(
-    start_profile: List[Vec3], end_profile: List[Vec3], quad: bool
+    start_profile: list[Vec3], end_profile: list[Vec3], quad: bool
 ) -> Iterator[Sequence[Vec3]]:
-    assert len(start_profile) == len(
-        end_profile
-    ), "profiles differ in vertex count"
+    assert len(start_profile) == len(end_profile), "profiles differ in vertex count"
     if quad:
         yield from _quad_connection_faces(start_profile, end_profile)
     else:
@@ -1323,8 +1269,6 @@ def reference_frame_z(heading: Vec3, origin: Vec3 = NULLVEC) -> UCS:
     Raises:
         ZeroDivisionError: heading is parallel to WCS Z_AXIS
 
-    .. versionadded:: 0.18
-
     """
     return UCS(uy=Z_AXIS.cross(heading), uz=heading, origin=origin)
 
@@ -1337,8 +1281,6 @@ def reference_frame_ext(frame: UCS, origin: Vec3 = NULLVEC) -> UCS:
         frame: previous reference frame
         origin: new UCS origin
 
-    .. versionadded:: 0.18
-
     """
     try:  # preserve x-axis
         return UCS(uy=Z_AXIS.cross(frame.ux), uz=Z_AXIS, origin=origin)
@@ -1363,8 +1305,8 @@ def _intersect_rays(
 def _intersection_profiles(
     start_profiles: Sequence[Sequence[Vec3]],
     end_profiles: Sequence[Sequence[Vec3]],
-) -> List[Sequence[Vec3]]:
-    profiles: List[Sequence[Vec3]] = [start_profiles[0]]
+) -> list[Sequence[Vec3]]:
+    profiles: list[Sequence[Vec3]] = [start_profiles[0]]
     rays = [
         [(v0, v1) for v0, v1 in zip(p0, p1)]
         for p0, p1 in zip(start_profiles, end_profiles)
@@ -1401,7 +1343,7 @@ def _make_sweep_start_and_end_profiles(
     profile: Iterable[UVec],
     sweeping_path: Iterable[UVec],
     next_ref_frame: Callable[[UCS, Vec3, Vec3], UCS],
-) -> Tuple[List[List[Vec3]], List[List[Vec3]]]:
+) -> tuple[list[list[Vec3]], list[list[Vec3]]]:
     spath = Vec3.list(sweeping_path)
     reference_profile = Vec3.list(profile)
     start_profiles = []
@@ -1419,7 +1361,7 @@ def _make_sweep_start_and_end_profiles(
 def sweep_profile(
     profile: Iterable[UVec],
     sweeping_path: Iterable[UVec],
-) -> List[Sequence[Vec3]]:
+) -> list[Sequence[Vec3]]:
     """Returns the intermediate profiles of sweeping a profile along a 3D path
     where the sweeping path defines the final location in the `WCS`.
 
@@ -1430,8 +1372,6 @@ def sweep_profile(
     Returns the start-, end- and all intermediate profiles along the sweeping
     path.
 
-    .. versionadded:: 0.18
-
     """
     return _intersection_profiles(
         *_make_sweep_start_and_end_profiles(
@@ -1444,10 +1384,10 @@ def debug_sweep_profiles(
     profile: Iterable[UVec],
     sweeping_path: Iterable[UVec],
     close=True,
-) -> List[Sequence[Vec3]]:
+) -> list[Sequence[Vec3]]:
     if close:
         profile = close_polygon(profile)
-    profiles: List[Sequence[Vec3]] = []
+    profiles: list[Sequence[Vec3]] = []
     for sp, ep in zip(
         *_make_sweep_start_and_end_profiles(
             profile, sweeping_path, make_next_reference_frame
@@ -1484,8 +1424,6 @@ def sweep(
         quads: use quadrilaterals as connection faces if ``True`` else triangles
         caps: close hull with top- and bottom faces (ngons)
 
-    .. versionadded:: 0.18
-
     """
     profiles = sweep_profile(profile, sweeping_path)
     return from_profiles_linear(
