@@ -1,6 +1,8 @@
-#  Copyright (c) 2021, Manfred Moitzi
-#  License: MIT License
-from typing import Sequence, Iterable, Optional, Tuple, List, NamedTuple
+# Copyright (c) 2021-2023, Manfred Moitzi
+# License: MIT License
+from __future__ import annotations
+from typing import Sequence, Iterable, Optional, Tuple, NamedTuple
+from typing_extensions import TypeAlias
 import abc
 import itertools
 import enum
@@ -134,6 +136,10 @@ clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.
 """
 
 
+class LayoutError(Exception):
+    pass
+
+
 class Stacking(enum.IntEnum):
     OVER = 0
     LINE = 1
@@ -201,14 +207,12 @@ class ContentRenderer(abc.ABC):
             m: transformation Matrix44
 
         """
-        pass
 
     @abc.abstractmethod
     def line(
         self, x1: float, y1: float, x2: float, y2: float, m: Matrix44 = None
     ) -> None:
         """Draw a line from (x1, y1) to (x2, y2)."""
-        pass
 
 
 class DoNothingRenderer(ContentRenderer):
@@ -228,8 +232,8 @@ class DoNothingRenderer(ContentRenderer):
         pass
 
 
-Tuple4f = Tuple[float, float, float, float]
-Tuple2f = Tuple[float, float]
+Tuple4f: TypeAlias = Tuple[float, float, float, float]
+Tuple2f: TypeAlias = Tuple[float, float]
 
 
 def resolve_margins(margins: Optional[Sequence[float]]) -> Tuple4f:
@@ -239,18 +243,16 @@ def resolve_margins(margins: Optional[Sequence[float]]) -> Tuple4f:
     count = len(margins)
     if count == 4:  # CSS: top, right, bottom, left
         return margins[0], margins[1], margins[2], margins[3]
-    elif count == 3:  # CSS: top, right, bottom, left=right
+    if count == 3:  # CSS: top, right, bottom, left=right
         return margins[0], margins[1], margins[2], margins[1]
-    elif count == 2:  # CSS: top, right, bottom=top, left=right
+    if count == 2:  # CSS: top, right, bottom=top, left=right
         return margins[0], margins[1], margins[0], margins[1]
-    elif count == 1:  # CSS: top, right=top, bottom=top, left=top
+    if count == 1:  # CSS: top, right=top, bottom=top, left=top
         return margins[0], margins[0], margins[0], margins[0]
     return 0, 0, 0, 0
 
 
-def insert_location(
-    align: LayoutAlignment, width: float, height: float
-) -> Tuple2f:
+def insert_location(align: LayoutAlignment, width: float, height: float) -> Tuple2f:
     """Returns the left top corner adjusted to the given alignment."""
     left: float = 0.0
     top: float = 0.0
@@ -280,41 +282,34 @@ def insert_location(
 class Box(abc.ABC):
     @property
     @abc.abstractmethod
-    def total_width(self) -> float:
-        pass
+    def total_width(self) -> float: ...
 
     @property
     @abc.abstractmethod
-    def total_height(self) -> float:
-        pass
+    def total_height(self) -> float: ...
 
     @abc.abstractmethod
     def place(self, x: float, y: float):
         """(x, y) is the top/left corner"""
-        pass
 
     @abc.abstractmethod
-    def final_location(self) -> Tuple[float, float]:
+    def final_location(self) -> tuple[float, float]:
         """Returns the final location as the top/left corner"""
-        pass
 
     @abc.abstractmethod
     def render(self, m: Matrix44 = None) -> None:
         """Render content at the final location."""
-        pass
 
     def bbox(self) -> BoundingBox2d:
-        """Returns the 2D bounding box of the container. If the cell is
-        not placed the top/left corner = (0, 0).
+        """Returns the 2D bounding box of the container. If the cell is not placed the 
+        top/left corner is (0, 0).
 
         """
         try:
             x, y = self.final_location()
-        except (ValueError, TypeError):
+        except (LayoutError, TypeError):
             x, y = 0, 0
-        return BoundingBox2d(
-            [(x, y), (x + self.total_width, y - self.total_height)]
-        )
+        return BoundingBox2d([(x, y), (x + self.total_width, y - self.total_height)])
 
 
 class Cell(Box):  # ABC
@@ -325,7 +320,7 @@ class Cell(Box):  # ABC
         # not necessary
         pass
 
-    def final_location(self) -> Tuple[float, float]:
+    def final_location(self) -> tuple[float, float]:
         # Base cells do not render anything, therefore final location is not
         # important
         return 0, 0
@@ -335,10 +330,13 @@ class Cell(Box):  # ABC
 
 
 class Glue(Cell):  # ABC
-    EMPTY: Tuple = tuple()
+    EMPTY: tuple = tuple()
 
     def __init__(
-        self, width: float, min_width: float = None, max_width: float = None
+        self,
+        width: float,
+        min_width: Optional[float] = None,
+        max_width: Optional[float] = None,
     ):
         self._width: float = float(width)
         self._min_width = float(min_width) if min_width else self._width
@@ -366,7 +364,7 @@ class Glue(Cell):  # ABC
     def total_height(self) -> float:
         return 0
 
-    def to_space(self) -> "Space":
+    def to_space(self) -> Space:
         return Space(self._width, self._min_width, self._max_width)
 
 
@@ -404,7 +402,7 @@ class ContentCell(Cell):  # ABC
         width: float,
         height: float,
         valign: CellAlignment = CellAlignment.BOTTOM,
-        renderer: ContentRenderer = None,
+        renderer: Optional[ContentRenderer] = None,
     ):
         self._final_x: Optional[float] = None
         self._final_y: Optional[float] = None
@@ -469,12 +467,12 @@ class Text(ContentCell):
         height: float,
         valign: CellAlignment = CellAlignment.BOTTOM,
         stroke: int = Stroke.NO_STROKE,
-        renderer: ContentRenderer = None,
+        renderer: Optional[ContentRenderer] = None,
     ):
         super().__init__(width, height, valign, renderer)
         self.stroke = int(stroke)  # public attribute read/write
 
-    def render(self, m: Matrix44 = None) -> None:
+    def render(self, m: Optional[Matrix44] = None) -> None:
         left, top = self.final_location()
         height = self.total_height
         bottom = top - height
@@ -516,7 +514,7 @@ def render_cells(cells: Iterable[Cell], m: Matrix44 = None) -> None:
             cell.render(m)
 
 
-def render_text_strokes(cells: List[Cell], m: Matrix44 = None) -> None:
+def render_text_strokes(cells: list[Cell], m: Matrix44 = None) -> None:
     """Render text cell strokes across glue cells."""
 
     # Should be called for container with horizontal arranged text cells
@@ -566,7 +564,7 @@ class Fraction(ContentCell):
         bottom: ContentCell,
         stacking: Stacking = Stacking.OVER,
         valign: CellAlignment = CellAlignment.BOTTOM,
-        renderer: ContentRenderer = None,
+        renderer: Optional[ContentRenderer] = None,
     ):
         super().__init__(0, 0, valign, renderer)
         self._stacking = stacking
@@ -581,9 +579,7 @@ class Fraction(ContentCell):
             self._height = top.total_height + bottom.total_height
             self._width = top.total_width + bottom.total_width
         else:
-            self._height = self.HEIGHT_SCALE * (
-                top.total_height + bottom.total_height
-            )
+            self._height = self.HEIGHT_SCALE * (top.total_height + bottom.total_height)
             self._width = max(top.total_width, bottom.total_width)
 
     def place(self, x: float, y: float):
@@ -595,7 +591,7 @@ class Fraction(ContentCell):
         top_content = self._top_content
         bottom_content = self._bottom_content
         if top_content is None or bottom_content is None:
-            raise ValueError("no content set")
+            raise LayoutError("no content set")
 
         if self._stacking == Stacking.SLANTED:
             top_content.place(x, y)  # left/top
@@ -640,7 +636,7 @@ _glue = (Space, NonBreakingSpace, Tabulator)
 _no_break = (Text, NonBreakingSpace)
 
 
-def normalize_cells(cells: Iterable[Cell]) -> List[Cell]:
+def normalize_cells(cells: Iterable[Cell]) -> list[Cell]:
     def replace_pending_nbsp_by_spaces():
         index = len(content) - 1
         while index >= 0:
@@ -664,10 +660,9 @@ def normalize_cells(cells: Iterable[Cell]) -> List[Cell]:
     cells = list(cells)
     prev = None
     for index, cell in enumerate(cells):
-
         if isinstance(cell, _content):
             if isinstance(prev, _content):
-                raise ValueError("no glue between content cells")
+                raise LayoutError("no glue between content cells")
         elif isinstance(cell, NonBreakingSpace) and is_useless_nbsp():
             cell = cell.to_space()
             replace_pending_nbsp_by_spaces()
@@ -686,9 +681,9 @@ class Container(Box):
     def __init__(
         self,
         width: Optional[float],
-        height: float = None,
-        margins: Sequence[float] = None,
-        renderer: ContentRenderer = None,
+        height: Optional[float] = None,
+        margins: Optional[Sequence[float]] = None,
+        renderer: Optional[ContentRenderer] = None,
     ):
         self._final_x: Optional[float] = None
         self._final_y: Optional[float] = None
@@ -712,7 +707,7 @@ class Container(Box):
 
     def final_location(self):
         if not self.is_placed():
-            raise ValueError("Container is not placed.")
+            raise LayoutError("Container is not placed.")
         return self._final_x, self._final_y
 
     def is_placed(self) -> bool:
@@ -770,7 +765,7 @@ class Container(Box):
         (x, y) is the top/left corner
         """
         if not self.is_placed():
-            raise ValueError("Layout has to be placed before rendering")
+            raise LayoutError("Layout has to be placed before rendering")
         if self.renderer:
             self.render_background(m)
         self.render_content(m)
@@ -821,7 +816,7 @@ class EmptyParagraph(Cell):
     def set_total_width(self, width: float):
         self._width = width
 
-    def distribute_content(self, height: float = None):
+    def distribute_content(self, height: Optional[float] = None):
         pass
 
     @property
@@ -832,13 +827,13 @@ class EmptyParagraph(Cell):
 class Paragraph(Container):
     def __init__(
         self,
-        width: float = None,  # defined by parent container
+        width: Optional[float] = None,  # defined by parent container
         align: ParagraphAlignment = ParagraphAlignment.LEFT,
-        indent: Tuple[float, float, float] = (0, 0, 0),
+        indent: tuple[float, float, float] = (0, 0, 0),
         line_spacing: float = 1,
-        margins: Sequence[float] = None,
-        tab_stops: Sequence[TabStop] = None,
-        renderer: ContentRenderer = None,
+        margins: Optional[Sequence[float]] = None,
+        tab_stops: Optional[Sequence[TabStop]] = None,
+        renderer: Optional[ContentRenderer] = None,
     ):
         super().__init__(width, None, margins, renderer)
         self._align = align
@@ -850,10 +845,10 @@ class Paragraph(Container):
         self._tab_stops = tab_stops or []
 
         # contains the raw and not distributed content:
-        self._cells: List[Cell] = []
+        self._cells: list[Cell] = []
 
         # contains the final distributed content:
-        self._lines: List[AbstractLine] = []
+        self._lines: list[AbstractLine] = []
 
         # space to next paragraph
         self._last_line_spacing = 0.0
@@ -868,7 +863,7 @@ class Paragraph(Container):
     def set_total_width(self, width: float):
         self._content_width = width - self.left_margin - self.right_margin
         if self._content_width < 1e-6:
-            raise ValueError("invalid width, no usable space left")
+            raise LayoutError("invalid width, no usable space left")
 
     def append_content(self, content: Iterable[Cell]):
         self._cells.extend(content)
@@ -915,7 +910,7 @@ class Paragraph(Container):
             height += last_line_height
         return height
 
-    def distribute_content(self, height: float = None) -> Optional["Paragraph"]:
+    def distribute_content(self, height: Optional[float] = None) -> Optional[Paragraph]:
         """Distribute the raw content into lines. Returns the cells which do
         not fit as a new paragraph.
 
@@ -939,9 +934,9 @@ class Paragraph(Container):
             elif align == ParagraphAlignment.CENTER:
                 return CenterLine(width)
             else:
-                raise ValueError(align)
+                raise LayoutError(align)
 
-        cells: List[Cell] = normalize_cells(self._cells)
+        cells: list[Cell] = normalize_cells(self._cells)
         cells = group_non_breakable_cells(cells)
         # Delete raw content:
         self._cells.clear()
@@ -975,6 +970,10 @@ class Paragraph(Container):
                     )
                     if append_state == SUCCESS:
                         index += 1  # consume tabulator
+                    elif not line.has_content:
+                        # The tabulator and the following word do no fit into a
+                        # line -> ignore the tabulator
+                        index += 1
                 else:
                     append_state = line.append(cell)
                 # state check order by probability:
@@ -1004,7 +1003,6 @@ class Paragraph(Container):
                     first = False
                     self._lines.append(line)
                     paragraph_height += leading(line_height, self._line_spacing)
-
         not_all_cells_processed = index < count
         if align == ParagraphAlignment.JUSTIFIED:
             # distribute justified text across the line width,
@@ -1024,7 +1022,7 @@ class Paragraph(Container):
         else:
             return None
 
-    def _new_paragraph(self, cells: List[Cell], first: bool) -> "Paragraph":
+    def _new_paragraph(self, cells: list[Cell], first: bool) -> Paragraph:
         # First line of the paragraph included?
         indent_first = self._indent_first if first else self._indent_left
         indent = (indent_first, self._indent_left, self._indent_right)
@@ -1045,17 +1043,17 @@ class Column(Container):
     def __init__(
         self,
         width: float,
-        height: float = None,
+        height: Optional[float] = None,
         gutter: float = 0,
-        margins: Sequence[float] = None,
-        renderer: ContentRenderer = None,
+        margins: Optional[Sequence[float]] = None,
+        renderer: Optional[ContentRenderer] = None,
     ):
         super().__init__(width, height, margins, renderer)
         # spacing between columns
         self._gutter = gutter
-        self._paragraphs: List[Paragraph] = []
+        self._paragraphs: list[Paragraph] = []
 
-    def clone_empty(self) -> "Column":
+    def clone_empty(self) -> Column:
         return self.__class__(
             width=self.content_width,
             height=self.content_height,
@@ -1091,8 +1089,7 @@ class Column(Container):
         height = 0.0
         if paragraphs:
             height = sum(
-                p.total_height + p.distance_to_next_paragraph
-                for p in paragraphs[:-1]
+                p.total_height + p.distance_to_next_paragraph for p in paragraphs[:-1]
             )
             height += paragraphs[-1].total_height
         return height
@@ -1119,10 +1116,8 @@ class Column(Container):
             p.place(x, y)
             y -= p.total_height + p.distance_to_next_paragraph
 
-    def append_paragraphs(
-        self, paragraphs: Iterable[Paragraph]
-    ) -> List[Paragraph]:
-        remainder: List[Paragraph] = []
+    def append_paragraphs(self, paragraphs: Iterable[Paragraph]) -> list[Paragraph]:
+        remainder: list[Paragraph] = []
         for paragraph in paragraphs:
             if remainder:
                 remainder.append(paragraph)
@@ -1143,14 +1138,14 @@ class Layout(Container):
     def __init__(
         self,
         width: float,
-        height: float = None,
-        margins: Sequence[float] = None,
-        renderer: ContentRenderer = None,
+        height: Optional[float] = None,
+        margins: Optional[Sequence[float]] = None,
+        renderer: Optional[ContentRenderer] = None,
     ):
         super().__init__(width, height, margins, renderer)
         self._reference_column_width = width
         self._current_column = 0
-        self._columns: List[Column] = []
+        self._columns: list[Column] = []
 
     def __iter__(self):
         return iter(self._columns)
@@ -1236,11 +1231,11 @@ class Layout(Container):
 
     def append_column(
         self,
-        width: float = None,
-        height: float = None,
+        width: Optional[float] = None,
+        height: Optional[float] = None,
         gutter: float = 0,
-        margins: Sequence[float] = None,
-        renderer: ContentRenderer = None,
+        margins: Optional[Sequence[float]] = None,
+        renderer: Optional[ContentRenderer] = None,
     ) -> Column:
         """Append a new column to the layout."""
         if not width:
@@ -1268,11 +1263,11 @@ class Layout(Container):
             self._current_column = len(self._columns) - 1
             remainder = column.append_paragraphs(remainder)
             if self._current_column > 100:
-                raise ValueError("Internal error - not enough space!?")
+                raise LayoutError("Internal error - not enough space!?")
 
     def _new_column(self) -> Column:
         if len(self._columns) == 0:
-            raise ValueError("no column exist")
+            raise LayoutError("no column exist")
         empty = self._columns[-1].clone_empty()
         self._columns.append(empty)
         return empty
@@ -1291,10 +1286,10 @@ def linear_placing(cells: Sequence[Cell], x: float, y: float):
 
 class RigidConnection(ContentCell):
     def __init__(
-        self, cells: Iterable[Cell] = None, valign=CellAlignment.BOTTOM
+        self, cells: Optional[Iterable[Cell]] = None, valign=CellAlignment.BOTTOM
     ):
         super().__init__(0, 0, valign=valign)
-        self._cells: List[Cell] = list(cells) if cells else []
+        self._cells: list[Cell] = list(cells) if cells else []
 
     def __iter__(self):
         return iter(self._cells)
@@ -1307,7 +1302,7 @@ class RigidConnection(ContentCell):
     def total_height(self) -> float:
         return max(cell.total_height for cell in self._cells)
 
-    def render(self, m: Matrix44 = None) -> None:
+    def render(self, m: Optional[Matrix44] = None) -> None:
         render_cells(self._cells, m)
         render_text_strokes(self._cells, m)
 
@@ -1317,13 +1312,11 @@ class RigidConnection(ContentCell):
 
     def growable_glue(self) -> Iterable[Glue]:
         return (
-            cell
-            for cell in self._cells
-            if isinstance(cell, Glue) and cell.can_grow
+            cell for cell in self._cells if isinstance(cell, Glue) and cell.can_grow
         )
 
 
-def group_non_breakable_cells(cells: List[Cell]) -> List[Cell]:
+def group_non_breakable_cells(cells: list[Cell]) -> list[Cell]:
     def append_rigid_content(s: int, e: int):
         _rigid_content = cells[s:e]
         if len(_rigid_content) > 1:
@@ -1380,7 +1373,7 @@ class AbstractLine(ContentCell):  # ABC
 
     def __init__(self, width: float):
         super().__init__(width=width, height=0, valign=CellAlignment.BOTTOM)
-        self._cells: List[LineCell] = []
+        self._cells: list[LineCell] = []
         self._current_offset: float = 0.0
 
     def __iter__(self):
@@ -1446,17 +1439,21 @@ class AbstractLine(ContentCell):  # ABC
         render_cells(cells, m)
         render_text_strokes(cells, m)
 
-    def remove_line_breaking_space(self):
-        """Remove the last space in the line."""
+    def remove_line_breaking_space(self) -> bool:
+        """Remove the last space in the line. Returns True if such a space was
+        removed.
+        """
         _cells = self._cells
         if _cells and isinstance(_cells[-1].cell, Space):
             _cells.pop()
+            return True
+        return False
 
 
 class LeftLine(AbstractLine):
     has_tab_support = True
 
-    def __init__(self, width: float, tab_stops: Sequence[TabStop] = None):
+    def __init__(self, width: float, tab_stops: Optional[Sequence[TabStop]] = None):
         super().__init__(width=width)
         self._tab_stops = tab_stops or []  # tab stops relative to line start
 
@@ -1491,8 +1488,7 @@ class LeftLine(AbstractLine):
         right_pos = pos + width
         tab_stop = self._next_tab_stop(left_pos, center_pos, right_pos)
         if tab_stop is None:  # no tab stop found
-            self.append(tab.to_space())  # replace tabulator by space
-            return self.append(cell)
+            return self._append_unlocked_tab(tab, cell)
         else:
             if tab_stop.kind == TabStopType.LEFT:
                 return self._append_left(cell, tab_stop.pos)
@@ -1501,6 +1497,19 @@ class LeftLine(AbstractLine):
             else:
                 return self._append_right(cell, tab_stop.pos)
 
+    def _append_unlocked_tab(self, tab, cell) -> AppendType:
+        pos0 = self._current_offset
+        space = tab.to_space()  # replace tabulator by space
+        pos1 = pos0 + space.total_width
+        width = cell.total_width
+        if pos1 + width <= self.line_width:
+            # The following cell is not locked and requires a space in front of it.
+            self._append_line_cell(space, pos0)
+            self._append_line_cell(cell, pos1)
+            self._current_offset = pos1 + width
+            return AppendType.SUCCESS
+        return AppendType.FAIL
+
     def _append_left(self, cell, pos) -> AppendType:
         width = cell.total_width
         if pos + width <= self.line_width:
@@ -1545,7 +1554,7 @@ def content_width(cells: Iterable[Cell]) -> float:
     return sum(cell.total_width for cell in cells)
 
 
-def growable_cells(cells: Iterable[Cell]) -> List[Glue]:
+def growable_cells(cells: Iterable[Cell]) -> list[Glue]:
     growable = []
     for cell in cells:
         if isinstance(cell, Glue) and cell.can_grow:
@@ -1555,7 +1564,7 @@ def growable_cells(cells: Iterable[Cell]) -> List[Glue]:
     return growable
 
 
-def update_offsets(cells: List[LineCell], index: int) -> None:
+def update_offsets(cells: list[LineCell], index: int) -> None:
     count = len(cells)
     if count == 0 or index > count:
         return
@@ -1664,7 +1673,7 @@ class RightLine(NoTabLine):
 
 def shift_tab_stops(
     tab_stops: Iterable[TabStop], offset: float, right_border: float
-) -> List[TabStop]:
+) -> list[TabStop]:
     return [
         tab_stop
         for tab_stop in (TabStop(pos + offset, kind) for pos, kind in tab_stops)
