@@ -2,7 +2,9 @@
 #  License: MIT License
 
 import pytest
-from ezdxf import shapefile, path
+from ezdxf.fonts import shapefile
+from ezdxf import path
+from ezdxf.math import BoundingBox2d
 
 
 def test_filter_noise():
@@ -146,7 +148,7 @@ class TestShapeRenderer:
 
     def test_render_bulges(self, shp):
         p = shp.render_shape(0x53)  # uppercase letter S
-        commands = p.commands()
+        commands = list(p.commands())
         assert [c.type for c in commands] == [
             path.Command.CURVE4_TO,
             path.Command.CURVE4_TO,
@@ -291,6 +293,21 @@ class TestShapeRenderer:
             p.end
         ), "should be perfect rendering - no placing-hack required"
 
+    def test_unsupported_non_printable_shape_number_returns_empty_path(self, shp):
+        cache = shapefile.GlyphCache(shp)
+        p = cache.get_shape(10)
+        assert len(p) == 0
+
+    def test_unsupported_printable_shape_number_returns_empty_box(self, shp):
+        cache = shapefile.GlyphCache(shp)
+        box = cache.get_shape(1234)
+        assert box is not cache.empty_box, "expected a copy"
+        assert box.command_codes() == cache.empty_box.command_codes()
+
+    def test_empty_box_has_advance_width_like_glyph_A(self, shp):
+        cache = shapefile.GlyphCache(shp)
+        assert cache.get_advance_width(1234) == cache.get_advance_width(65)
+
 
 FILE_1 = b"""
 ;; isocp.shp
