@@ -17,6 +17,5 @@ def test_random_3d_path():
     assert len(set(points)) > 97
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pytest.main([__file__])
-
